Skip to content
KitploitKITPLOIT
OutilsExploitsBlog
Log in
Soumettre
OutilsExploitsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

··Flux·Contact·Confidentialité·© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
CVE-2024-6387_Check — CVE-2024-6387_Check est un outil léger et efficace conçu pour identifier les serveurs exécutant des versions vulnérables d'OpenSSH. | Kitploit
Outils/GitHubGitHub/xaitax/cve-2024-6387_check
ReconnaissanceScanners de VulnérabilitésExploitationCollecte d'InformationsSécurité RéseauTests d'Intrusion
GitHubxaitax/cve-2024-6387_check

CVE-2024-6387_Check

CVE-2024-6387_Check est un outil léger et efficace conçu pour identifier les serveurs exécutant des versions vulnérables d'OpenSSH.

Voir le dépôt
52610014il y a 4 moisVérifié par Kitploit

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Partager

CVE-2024-6387_Check

image

📜 Description

CVE-2024-6387_Check est un outil léger et efficace conçu pour identifier les serveurs exécutant des versions vulnérables d'OpenSSH, ciblant spécifiquement la vulnérabilité regreSSHion récemment découverte (CVE-2024-6387). Ce script facilite l'analyse rapide de plusieurs adresses IP, noms de domaine et plages réseau CIDR afin de détecter les vulnérabilités potentielles et de garantir la sécurité de votre infrastructure.

🌟 Fonctionnalités

  • Analyse rapide : Analysez rapidement plusieurs adresses IP, noms de domaine et plages CIDR pour détecter la vulnérabilité CVE-2024-6387.
  • Récupération de bannière : Récupère efficacement les bannières SSH sans authentification.
  • Détection du délai de grâce : Détecte optionnellement si les serveurs ont atténué les vulnérabilités en utilisant le paramètre LoginGraceTime.
  • Prise en charge IPv6 : Prend entièrement en charge les adresses IPv6 pour l'analyse directe et par nom d'hôte.
  • Multi-threading : Utilise le threading pour des vérifications concurrentes, réduisant considérablement les temps d'analyse.
  • Sortie détaillée : Fournit une sortie claire et codée par emojis résumant les résultats de l'analyse.
  • Vérification des ports : Identifie les ports fermés et fournit un résumé des hôtes non répondants.
  • Détection des versions corrigées : Reconnaît et exclut les versions corrigées connues des rapports de vulnérabilité.
  • Résolution DNS / nom d'hôte : Résout et affiche les noms d'hôte pour les adresses IP.

🚀 Utilisation

python CVE-2024-6387_Check.py <targets> [--ports PORTS] [--timeout TIMEOUT] [--list FILE] [--grace-time-check [SECONDS]] [--dns-resolve] [--use-help-request]

Arguments de la ligne de commande

  • <targets> : Adresses IP, noms de domaine, chemins de fichiers contenant des adresses IP ou plages réseau CIDR.
  • --timeout TIMEOUT : Définit le délai de connexion en secondes (par défaut : 1 seconde).
  • --list FILE : Fichier contenant une liste d'adresses IP à vérifier.
  • --ports PORTS : Spécifie une liste de numéros de ports séparés par des virgules à vérifier (par défaut : 22).
  • --use-help-request : Active l'envoi d'une requête HELP si la récupération initiale de la bannière SSH échoue.
  • --grace-time-check [SECONDS] : Temps en secondes à attendre après l'identification de la version pour vérifier l'atténuation LoginGraceTime (par défaut : 120 secondes).
  • --dns-resolve : Résout et affiche les noms d'hôte pour les adresses IP.

Exemples

Adresse IP unique

python CVE-2024-6387_Check.py 192.168.1.1

Adresses IP depuis un fichier

python CVE-2024-6387_Check.py -l ip_list.txt

Plusieurs adresses IP et domaines

python CVE-2024-6387_Check.py 192.168.1.1 example.com 192.168.1.2

Plage CIDR

python CVE-2024-6387_Check.py 192.168.1.0/24

Avec plusieurs ports

python CVE-2024-6387_Check.py 192.168.1.1 example.com --ports 22,2222

Vérification de l'atténuation LoginGraceTime

python CVE-2024-6387_Check.py 192.168.1.1 --grace-time-check

Vérification de l'atténuation LoginGraceTime avec un délai personnalisé

python CVE-2024-6387_Check.py 192.168.1.1 --grace-time-check 150

Activation de la requête HELP

python CVE-2024-6387_Check.py 192.168.1.1 --use-help-request

Activation de la résolution DNS / nom d'hôte

python CVE-2024-6387_Check.py 192.168.1.1 --dns-resolve

✨ Fonctionnalités expliquées

Détection du délai de grâce

L'outil prend en charge la vérification de l'atténuation de LoginGraceTime. Lorsque l'option --grace-time-check est utilisée, le script attend la durée spécifiée après avoir récupéré la bannière SSH pour voir si la connexion reste ouverte, ce qui indique que le paramètre LoginGraceTime pourrait être défini sur 0 comme mesure d'atténuation.

Prise en charge IPv6

L'outil prend entièrement en charge les adresses IPv6. Vous pouvez analyser les adresses IPv4 et IPv6 directement ou via la résolution de noms d'hôte.

Détection des versions corrigées

L'outil reconnaît certaines versions corrigées d'OpenSSH et les exclut du rapport de vulnérabilité, garantissant des résultats plus précis.

Résolution DNS / nom d'hôte

Lorsque l'option --dns-resolve est utilisée, le script résout et affiche les noms d'hôte pour les adresses IP dans la sortie. Cette fonctionnalité permet d'identifier plus clairement les hôtes analysés.

Gestion des requêtes HELP

L'outil inclut une option pour gérer les services SSH restrictifs qui ne renvoient pas immédiatement de bannière. Lorsque l'option --use-help-request est utilisée, le script envoie une requête "HELP" si la récupération initiale de la bannière SSH échoue, augmentant ainsi les détections "d'atténuation".

Sortie

Le script fournira un résumé des cibles analysées :

  • 🚨 Vulnérables : serveurs exécutant une version vulnérable d'OpenSSH.
  • 🛡️ Non vulnérables : serveurs exécutant une version non vulnérable d'OpenSSH.
  • ⚠️ Inconnus : serveurs exécutant une version inconnue de SSH
  • 🔒 Ports fermés : nombre de serveurs dont le port 22 (ou le port spécifié) est fermé.
  • 📊 Total analysé : nombre total de cibles analysées.
🛡️ Servers not vulnerable: 2

   [+] Server at somedomain.cloudapp.azure.com (running SSH-2.0-OpenSSH_8.2p1 Ubuntu-4ubuntu0.11)
   [+] Server at regresshion_test.cc (running SSH-2.0-OpenSSH_9.6p1 Ubuntu-3ubuntu13.3)

🚨 Servers likely vulnerable: 1

   [+] Server at 4.231.170.122 (abc.com) (running SSH-2.0-OpenSSH_9.2p1 Debian-2+deb12u2)
   [+] Server at 4.231.170.121 (running SSH-2.0-OpenSSH_9.2p1 Debian-2+deb12u2) vulnerable and LoginGraceTime remediation not done (Session was closed by server at 120.1 seconds)

⚠️ Servers with unknown SSH version: 1

   [+] Server at 103.97.85.85 (xxx.com) (banner: SSH-2.0-ROSSSH)

🔒 Servers with port 22 closed: 254

📊 Total scanned targets: 257

📆 Journal des modifications

[08 juillet 2024] - Version 0.8

  • [Ajouté] Inclusion des versions corrigées pour FreeBSD 13.3, 14.x et 15
  • [Ajouté] Résolution de noms d'hôte via -d ou --dns-resolve
  • [Corrigé] Détection de LoginGraceTime @agibson2

[06 juillet 2024] - Version 0.7

  • [Ajouté] Introduction d'une option permettant d'utiliser une requête "HELP" pour récupérer la bannière SSH si la tentative initiale échoue. Cette fonctionnalité peut être activée à l'aide de l'argument --use-help-request. Cela permet de contourner certaines configurations SSH qui ne renvoient pas immédiatement la bannière, améliorant ainsi la compatibilité avec les services SSH plus restrictifs.
  • [Ajouté] #30 Permet l'analyse de plusieurs ports.

[05 juillet 2024] - Version 0.6

  • [Ajouté] Introduction de la détection de LoginGraceTime.
  • [Corrigé] Résolution du problème où les hôtes possédant uniquement une adresse IPv6 ne pouvaient pas être testés par nom d'hôte.

📚 Références

Blog de Qualys sur la vulnérabilité regreSSHion

Télécharger l’outil